@@ -154,8 +154,7 @@ espeak__get_synthesizerVersion (PortableServer_Servant
 				servant,
 				CORBA_Environment * ev)
 {
-  //	char version[VERSION_LENGTH];
-  return CORBA_string_dup ("????"); /* TBD */
+  return CORBA_string_dup (espeak_Info(NULL));
 }
 
 
